@@ -93,7 +93,8 @@ class MountHelper(object):
         self.rebuildCache()
 
     def _readdata(self):
-        return open(self.data_file, 'r').read()
+        with open(self.data_file, 'r') as f:
+            return f.read()
 
     def rebuildCache(self):
         """Rebuild cache from fstab file"""
@@ -217,13 +218,13 @@ def childMounts(pathname):
     mtabFile = '/etc/mtab'
     if not os.access(mtabFile, os.R_OK):
         return ""
-    return reduce(lambda x, y: x + [y],
-                  filter(lambda x: commonPath(absPath, x[0]) == absPath or \
-                                   commonPath(absPath, x[1]) == absPath,
-                         map(lambda x: [x[0], x[1]],
-                             map(lambda x: x.split(" "),
-                                 open(mtabFile)))),
-                  [])
+    with open(mtabFile) as f:
+        return reduce(lambda x, y: x + [y],
+                      filter(lambda x: commonPath(absPath, x[0]) == absPath or \
+                                       commonPath(absPath, x[1]) == absPath,
+                             map(lambda x: [x[0], x[1]],
+                                 map(lambda x: x.split(" "), f))),
+                      [])
 
 class MountError(Exception):
     pass
